<?php

/**
 * @file
 *
 * Custom contributor rendering.
 */

/**
 * Custom render_contriubutors implementation to display authors as links if
 * they are linked to nodes.
 */
class biblio_author_node_handler_field_contributor extends biblio_handler_field_contributor {
  function render_contriubutors($contributors) {
    $authors = array();
    if (!isset($this->alnum)) {
      list($this->alnum, $this->alpha, $this->cntrl, $this->dash,
          $this->digit, $this->graph, $this->lower, $this->print,
          $this->punct, $this->space, $this->upper, $this->word,
          $this->patternModifiers) = $this->get_regex_patterns();
    }

    foreach ($contributors as $rank => $author) {
      $author = (object)$author;
      if ($author->literal == 1) {
        $authors[] = $author->name;
      }
      else {
        if (!empty($author->firstname) && $this->options['initialize'] == 1) {
          $author->firstname = preg_replace("/([$this->upper])[$this->lower]+/$this->patternModifiers", '\\1', $author->firstname);
          $author->firstname = preg_replace("/(?<=[-$this->upper]) +(?=[-$this->upper])/$this->patternModifiers", "", $author->firstname);
          $author->initials = $author->firstname . $author->initials;
        }
        if (isset($author->initials)) {
          // within initials, remove any dots:
          $author->initials = preg_replace("/([$this->upper])\.+/$this->patternModifiers", "\\1", $author->initials);
          // within initials, remove any spaces *between* initials:
          $author->initials = preg_replace("/(?<=[-$this->upper]) +(?=[-$this->upper])/$this->patternModifiers", "", $author->initials);
          if ($this->options['initialize_with_hyphen'] === FALSE) {
            $author->initials = preg_replace("/-/", '', $author->initials);
          }
          // within initials, add a space after a hyphen, but only if ...
          if (preg_match("/ $/", $this->options['initialize_with'])) {// ... the delimiter that separates initials ends with a space
            $author->initials = preg_replace("/-(?=[$this->upper])/$this->patternModifiers", "- ", $author->initials);
          }
          // then, separate initials with the specified delimiter:
          $init_sep = $this->options['initialize_with'];
          $author->initials = preg_replace("/([$this->upper])(?=[^$this->lower]+|$)/$this->patternModifiers", "\\1$init_sep", $author->initials);

          //      $shortenInitials = (isset($options['numberOfInitialsToKeep)) ? $options['numberOfInitialsToKeep : FALSE;
          //      if ($shortenInitials) $given = drupal_substr($given, 0, $shortenInitials);

          if ($this->options['initialize'] == 1) {
            $author->firstname = $author->initials;
            // if ($shortenInitials) $author->firstname = drupal_substr($author->firstname, 0, $shortenInitials);
          }
          elseif (!empty($author->firstname)) {
            $author->firstname = $author->firstname . ' ' . $author->initials;
          }
          elseif (empty($author->firstname)) {
            $author->firstname = $author->initials;
          }
        }

        if (!empty($author->drupal_nid)) {
	      $link = base_path() . drupal_get_path_alias('node/' . $author->drupal_nid);
	      $link_pre = '<a href="' . $link . '">';
	      $link_post = '</a>';
	    }
	    else if (!empty($author->cid)) {
	      $link = base_path() . variable_get('biblio_base', 'bibliography') . '?f[author]=' . $author->cid;
	      $link_pre = '<a href="' . $link . '">';
	      $link_post = '</a>';
	    }
	    else {
		  $link_pre = '';
		  $link_post = '';
	    }

        if (isset($author->lastname)) {
          if ($this->options['short_form'] == 1) {
            $authors[] = $link_pre . $author->lastname . $link_post;
          }
          else {
            switch ($this->options['name_order']) {
              case 'last-first':
                $authors[] = $link_pre . $author->lastname . $this->options['sort_separator'] . $author->firstname . $link_post;
                break;
              default:
                $authors[] = $link_pre . $author->firstname . ' ' . $author->lastname . $link_post;
            }
          }
        }
      }
    }

    return implode($this->options['separator'], $authors);
  }
}
